[![PyPI version](https://badge.fury.io/py/sos-bioinfo.svg)](https://badge.fury.io/py/sos-bioinfo)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/6bfa650c4f1f4db1a96f010a6c30b4f5)](https://www.codacy.com/app/BoPeng/sos-bioinfo?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=vatlab/sos-bioinfo&amp;utm_campaign=Badge_Grade)

# sos-bioinfo
Bioinformatics extensions for SoS. Please refer to [SoS Homepage](http://vatlab.github.io/SoS/) for details.

